defaultConfig property
Default track configuration used when timeline is created. Always present and cannot be removed from the timeline.
Implementation
@override
final TrackConfig defaultConfig;
Default track configuration used when timeline is created. Always present and cannot be removed from the timeline.
@override
final TrackConfig defaultConfig;