TranslateTransition class

A widget that applies a translate transform based on an animation.

Inheritance
Available extensions

Constructors

TranslateTransition({Key? key, required Widget child, required Animation<Offset> offset, bool transformHitTests = true})
Creates a TranslateTransition with the given configuration.
const

Properties

child → Widget
The child widget to transform.
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
listenable → Listenable
The Listenable to which this widget is listening.
finalinherited
offset → Animation<Offset>
The animation that provides the offset values.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transformHitTests → bool
Whether to transform hit tests to match the visual translation.
final

Methods

act(List<Act> acts, {CueMotion? motion, CueMotion? reverseMotion, Duration delay = Duration.zero, Duration reverseDelay = Duration.zero}) → Widget

Available on Widget, provided by the ActorExtenstion extension

Wraps this widget with an Actor using the provided acts.
build(BuildContext context) → Widget
Override this method to build widgets that depend on the state of the listenable (e.g., the current value of the animation).
override
createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<AnimatedWidget>
Subclasses typically do not override this method.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited