MotionKeyframes<T> class
final
Keyframe sequence with explicit motion timing between frames.
Each frame specifies its own CueMotion to determine animation timing from the previous frame. Motions are extracted and applied sequentially.
- Implemented types
-
- Keyframes<
T>
- Keyframes<
Constructors
-
MotionKeyframes(List<
Keyframe< frames, {required CueMotion motion})T> > -
Creates a MotionKeyframes with explicit motion timing.
const
Properties
-
frames
→ List<
Keyframe< T> > -
The ordered list of keyframes with explicit motion.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- lastTarget → T
-
The final target value in the keyframe sequence.
no setteroverride
- motion → CueMotion
-
The default motion used when a keyframe doesn't specify one.
final
-
reversed
→ MotionKeyframes<
T> -
The keyframe sequence reversed.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
values
→ List<
T> -
All target values in the keyframe sequence.
no setteroverride
Methods
-
extractMotion(
{bool includeFirst = false}) → List< CueMotion> - Extracts motions from each keyframe, optionally including the first.
-
mapValues<
E> (E transform(T value)) → MotionKeyframes< E> -
Maps each value in the keyframes to a new type.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override